%define upstream_name Class-Tiny
%define upstream_version 1.008

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1

Summary:    Minimalist class construction
License:    ASL 2.0
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Class/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(Test::More) >= 0.960.0
BuildRequires: perl(base)
BuildRequires: perl(lib)
BuildRequires: perl(strict)
BuildRequires: perl(subs)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
This module offers a minimalist class construction kit in around 120
lines of code. Here is a list of features:

*   defines attributes via import arguments
*   generates read-write accessors
*   supports lazy attribute defaults
*   supports custom accessors
*   superclass provides a standard "new" constructor
*   "new" takes a hash reference or list of key/value pairs
*   "new" has heuristics to catch constructor attribute typos
*   "new" calls "BUILD" for each class from parent to child
*   superclass provides a "DESTROY" method
*   "DESTROY" calls "DEMOLISH" for each class from child to parent

It uses no non-core modules for any recent Perl. On Perls older than
v5.10 it requires MRO::Compat. On Perls older than v5.14, it requires
Devel::GlobalDestruction.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Sat Sep 05 2020 tv <tv> 1.8.0-1.mga8
+ Revision: 1622328
- update to 1.008

* Wed Feb 12 2020 umeabot <umeabot> 1.6.0-3.mga8
+ Revision: 1503583
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 1.6.0-2.mga7
+ Revision: 1282272
- Mageia 7 Mass Rebuild
+ sander85 <sander85>
- update to 1.006

* Wed Jul 19 2017 sander85 <sander85> 1.6.0-1.mga7
+ Revision: 1125061
- update to 1.006
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Sun Nov 15 2015 tv <tv> 1.4.0-1.mga6
+ Revision: 903337
- new release

* Sun Jun 21 2015 sander85 <sander85> 1.1.0-1.mga6
+ Revision: 837066
- update to 1.001

* Sun Oct 19 2014 umeabot <umeabot> 1.0.0-4.mga5
+ Revision: 790272
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.0.0-3.mga5
+ Revision: 741520
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.0.0-2.mga5
+ Revision: 683946
- Mageia 5 Mass Rebuild

* Thu Jul 17 2014 sander85 <sander85> 1.0.0-1.mga5
+ Revision: 653386
- update to 1.000

* Tue Jul 15 2014 sander85 <sander85> 0.15.0-1.mga5
+ Revision: 653013
- update to 0.015

* Thu Feb 06 2014 sander85 <sander85> 0.14.0-1.mga5
+ Revision: 584557
- update to 0.014

* Mon Oct 21 2013 umeabot <umeabot> 0.11.0-2.mga4
+ Revision: 537117
- Mageia 4 Mass Rebuild

* Wed Sep 25 2013 sander85 <sander85> 0.11.0-1.mga4
+ Revision: 486348
- update to 0.011

* Tue Sep 24 2013 sander85 <sander85> 0.10.0-1.mga4
+ Revision: 485532
- update to 0.010

* Sun Sep 15 2013 sander85 <sander85> 0.8.0-1.mga4
+ Revision: 479848
- imported package perl-Class-Tiny

